from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EfficiencyCls:
	"""Efficiency commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("efficiency", core, parent)

	# noinspection PyTypeChecker
	def get_replies(self) -> enums.AvionicDmeReplCount:
		"""SCPI: [SOURce<HW>]:[BB]:DME:EFFiciency:REPLies \n
		Snippet: value: enums.AvionicDmeReplCount = driver.source.bb.dme.efficiency.get_replies() \n
		Sets the number of reply pulses. Use this number to specify absolute values of false or correct pulses during reply
		efficiency measurements. \n
			:return: no_of_replies: 10| 50| 100 10, 50 or 100 reply pulses
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:EFFiciency:REPLies?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicDmeReplCount)

	def set_replies(self, no_of_replies: enums.AvionicDmeReplCount) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:EFFiciency:REPLies \n
		Snippet: driver.source.bb.dme.efficiency.set_replies(no_of_replies = enums.AvionicDmeReplCount._10) \n
		Sets the number of reply pulses. Use this number to specify absolute values of false or correct pulses during reply
		efficiency measurements. \n
			:param no_of_replies: 10| 50| 100 10, 50 or 100 reply pulses
		"""
		param = Conversions.enum_scalar_to_str(no_of_replies, enums.AvionicDmeReplCount)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:EFFiciency:REPLies {param}')

	def get_value(self) -> int:
		"""SCPI: [SOURce<HW>]:[BB]:DME:EFFiciency \n
		Snippet: value: int = driver.source.bb.dme.efficiency.get_value() \n
		Sets the relation between reply pulse pairs and received trigger signals, e.g. with a set efficiency of 50% only every
		second trigger event leads to the generation of a reply pulse pair. \n
			:return: efficiency: integer Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:EFFiciency?')
		return Conversions.str_to_int(response)

	def set_value(self, efficiency: int) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:EFFiciency \n
		Snippet: driver.source.bb.dme.efficiency.set_value(efficiency = 1) \n
		Sets the relation between reply pulse pairs and received trigger signals, e.g. with a set efficiency of 50% only every
		second trigger event leads to the generation of a reply pulse pair. \n
			:param efficiency: integer Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(efficiency)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:EFFiciency {param}')



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PdschCls:
	"""Pdsch commands group definition. 73 total commands, 28 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdsch", core, parent)

	@property
	def ag12(self):
		"""ag12 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ag12'):
			from .Ag12 import Ag12Cls
			self._ag12 = Ag12Cls(self._core, self._cmd_group)
		return self._ag12

	@property
	def ap12(self):
		"""ap12 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ap12'):
			from .Ap12 import Ap12Cls
			self._ap12 = Ap12Cls(self._core, self._cmd_group)
		return self._ap12

	@property
	def cbgf(self):
		"""cbgf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_cbgf'):
			from .Cbgf import CbgfCls
			self._cbgf = CbgfCls(self._core, self._cmd_group)
		return self._cbgf

	@property
	def di12(self):
		"""di12 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_di12'):
			from .Di12 import Di12Cls
			self._di12 = Di12Cls(self._core, self._cmd_group)
		return self._di12

	@property
	def dmta(self):
		"""dmta commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmta'):
			from .Dmta import DmtaCls
			self._dmta = DmtaCls(self._core, self._cmd_group)
		return self._dmta

	@property
	def dmtb(self):
		"""dmtb commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmtb'):
			from .Dmtb import DmtbCls
			self._dmtb = DmtbCls(self._core, self._cmd_group)
		return self._dmtb

	@property
	def dsid(self):
		"""dsid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dsid'):
			from .Dsid import DsidCls
			self._dsid = DsidCls(self._core, self._cmd_group)
		return self._dsid

	@property
	def ha12(self):
		"""ha12 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ha12'):
			from .Ha12 import Ha12Cls
			self._ha12 = Ha12Cls(self._core, self._cmd_group)
		return self._ha12

	@property
	def hp5Bits(self):
		"""hp5Bits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hp5Bits'):
			from .Hp5Bits import Hp5BitsCls
			self._hp5Bits = Hp5BitsCls(self._core, self._cmd_group)
		return self._hp5Bits

	@property
	def lselected(self):
		"""lselected commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lselected'):
			from .Lselected import LselectedCls
			self._lselected = LselectedCls(self._core, self._cmd_group)
		return self._lselected

	@property
	def maOffset(self):
		"""maOffset commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_maOffset'):
			from .MaOffset import MaOffsetCls
			self._maOffset = MaOffsetCls(self._core, self._cmd_group)
		return self._maOffset

	@property
	def mcbGroups(self):
		"""mcbGroups commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcbGroups'):
			from .McbGroups import McbGroupsCls
			self._mcbGroups = McbGroupsCls(self._core, self._cmd_group)
		return self._mcbGroups

	@property
	def mcsTable(self):
		"""mcsTable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcsTable'):
			from .McsTable import McsTableCls
			self._mcsTable = McsTableCls(self._core, self._cmd_group)
		return self._mcsTable

	@property
	def mcwdci(self):
		"""mcwdci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcwdci'):
			from .Mcwdci import McwdciCls
			self._mcwdci = McwdciCls(self._core, self._cmd_group)
		return self._mcwdci

	@property
	def pi11(self):
		"""pi11 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pi11'):
			from .Pi11 import Pi11Cls
			self._pi11 = Pi11Cls(self._core, self._cmd_group)
		return self._pi11

	@property
	def pi12(self):
		"""pi12 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pi12'):
			from .Pi12 import Pi12Cls
			self._pi12 = Pi12Cls(self._core, self._cmd_group)
		return self._pi12

	@property
	def prec(self):
		"""prec commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_prec'):
			from .Prec import PrecCls
			self._prec = PrecCls(self._core, self._cmd_group)
		return self._prec

	@property
	def rbgSize(self):
		"""rbgSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbgSize'):
			from .RbgSize import RbgSizeCls
			self._rbgSize = RbgSizeCls(self._core, self._cmd_group)
		return self._rbgSize

	@property
	def resAlloc(self):
		"""resAlloc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_resAlloc'):
			from .ResAlloc import ResAllocCls
			self._resAlloc = ResAllocCls(self._core, self._cmd_group)
		return self._resAlloc

	@property
	def rv12(self):
		"""rv12 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rv12'):
			from .Rv12 import Rv12Cls
			self._rv12 = Rv12Cls(self._core, self._cmd_group)
		return self._rv12

	@property
	def scrambling(self):
		"""scrambling commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_scrambling'):
			from .Scrambling import ScramblingCls
			self._scrambling = ScramblingCls(self._core, self._cmd_group)
		return self._scrambling

	@property
	def tci(self):
		"""tci commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tci'):
			from .Tci import TciCls
			self._tci = TciCls(self._core, self._cmd_group)
		return self._tci

	@property
	def td(self):
		"""td commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_td'):
			from .Td import TdCls
			self._td = TdCls(self._core, self._cmd_group)
		return self._td

	@property
	def tdaLists(self):
		"""tdaLists commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tdaLists'):
			from .TdaLists import TdaListsCls
			self._tdaLists = TdaListsCls(self._core, self._cmd_group)
		return self._tdaLists

	@property
	def tdaNum(self):
		"""tdaNum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tdaNum'):
			from .TdaNum import TdaNumCls
			self._tdaNum = TdaNumCls(self._core, self._cmd_group)
		return self._tdaNum

	@property
	def tdml(self):
		"""tdml commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tdml'):
			from .Tdml import TdmlCls
			self._tdml = TdmlCls(self._core, self._cmd_group)
		return self._tdml

	@property
	def vpInter(self):
		"""vpInter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vpInter'):
			from .VpInter import VpInterCls
			self._vpInter = VpInterCls(self._core, self._cmd_group)
		return self._vpInter

	@property
	def xoverhead(self):
		"""xoverhead commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xoverhead'):
			from .Xoverhead import XoverheadCls
			self._xoverhead = XoverheadCls(self._core, self._cmd_group)
		return self._xoverhead

	def clone(self) -> 'PdschCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PdschCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, use_def_ap: bool, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:APERture:DEFault:STATe \n
		Snippet: driver.sense.power.aperture.default.state.set(use_def_ap = False, channel = repcap.Channel.Default) \n
		Deactivates the default aperture time of the respective sensor. To specify a user-defined value, use the command method
		RsSmbv.Sense.Power.Aperture.Time.set. \n
			:param use_def_ap: 1| ON| 0| OFF
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
		"""
		param = Conversions.bool_to_str(use_def_ap)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:APERture:DEFault:STATe {param}')

	def get(self, channel=repcap.Channel.Default) -> bool:
		"""SCPI: SENSe<CH>:[POWer]:APERture:DEFault:STATe \n
		Snippet: value: bool = driver.sense.power.aperture.default.state.get(channel = repcap.Channel.Default) \n
		Deactivates the default aperture time of the respective sensor. To specify a user-defined value, use the command method
		RsSmbv.Sense.Power.Aperture.Time.set. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: use_def_ap: 1| ON| 0| OFF"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:APERture:DEFault:STATe?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectAllCls:
	"""SelectAll commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("selectAll", core, parent)

	def set(self, selectAllNull=repcap.SelectAllNull.Nr0) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:SELectlall<ST0> \n
		Snippet: driver.source.bb.eutra.downlink.emtc.bmp.selectAll.set(selectAllNull = repcap.SelectAllNull.Nr0) \n
		Sets all SFs as valid or invalid. \n
			:param selectAllNull: optional repeated capability selector. Default value: Nr0
		"""
		selectAllNull_cmd_val = self._cmd_group.get_repcap_cmd_value(selectAllNull, repcap.SelectAllNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:SELectlall{selectAllNull_cmd_val}')

	def set_with_opc(self, selectAllNull=repcap.SelectAllNull.Nr0, opc_timeout_ms: int = -1) -> None:
		selectAllNull_cmd_val = self._cmd_group.get_repcap_cmd_value(selectAllNull, repcap.SelectAllNull)
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:SELectlall<ST0> \n
		Snippet: driver.source.bb.eutra.downlink.emtc.bmp.selectAll.set_with_opc(selectAllNull = repcap.SelectAllNull.Nr0) \n
		Sets all SFs as valid or invalid. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param selectAllNull: optional repeated capability selector. Default value: Nr0
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:SELectlall{selectAllNull_cmd_val}', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DmeCls:
	"""Dme commands group definition. 91 total commands, 14 Subgroups, 14 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dme", core, parent)

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def ppst(self):
		"""ppst commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ppst'):
			from .Ppst import PpstCls
			self._ppst = PpstCls(self._core, self._cmd_group)
		return self._ppst

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def trigger(self):
		"""trigger commands group. 4 Sub-classes, 4 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def analysis(self):
		"""analysis commands group. 1 Sub-classes, 11 commands."""
		if not hasattr(self, '_analysis'):
			from .Analysis import AnalysisCls
			self._analysis = AnalysisCls(self._core, self._cmd_group)
		return self._analysis

	@property
	def echo(self):
		"""echo commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_echo'):
			from .Echo import EchoCls
			self._echo = EchoCls(self._core, self._cmd_group)
		return self._echo

	@property
	def efficiency(self):
		"""efficiency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_efficiency'):
			from .Efficiency import EfficiencyCls
			self._efficiency = EfficiencyCls(self._core, self._cmd_group)
		return self._efficiency

	@property
	def flight(self):
		"""flight commands group. 4 Sub-classes, 4 commands."""
		if not hasattr(self, '_flight'):
			from .Flight import FlightCls
			self._flight = FlightCls(self._core, self._cmd_group)
		return self._flight

	@property
	def gaussian(self):
		"""gaussian commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gaussian'):
			from .Gaussian import GaussianCls
			self._gaussian = GaussianCls(self._core, self._cmd_group)
		return self._gaussian

	@property
	def icao(self):
		"""icao commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_icao'):
			from .Icao import IcaoCls
			self._icao = IcaoCls(self._core, self._cmd_group)
		return self._icao

	@property
	def id(self):
		"""id commands group. 2 Sub-classes, 11 commands."""
		if not hasattr(self, '_id'):
			from .Id import IdCls
			self._id = IdCls(self._core, self._cmd_group)
		return self._id

	@property
	def marker(self):
		"""marker commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import MarkerCls
			self._marker = MarkerCls(self._core, self._cmd_group)
		return self._marker

	@property
	def pinput(self):
		"""pinput commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_pinput'):
			from .Pinput import PinputCls
			self._pinput = PinputCls(self._core, self._cmd_group)
		return self._pinput

	@property
	def rdistance(self):
		"""rdistance commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rdistance'):
			from .Rdistance import RdistanceCls
			self._rdistance = RdistanceCls(self._core, self._cmd_group)
		return self._rdistance

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:DME:PRESet \n
		Snippet: driver.source.bb.dme.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:VOR|ILS|DME:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:DME:PRESet \n
		Snippet: driver.source.bb.dme.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:VOR|ILS|DME:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:DME:PRESet', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DME:STATe \n
		Snippet: value: bool = driver.source.bb.dme.get_state() \n
		Activates/deactivates the avionic standard. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:DME:STATe \n
		Snippet: driver.source.bb.dme.set_state(state = False) \n
		Activates/deactivates the avionic standard. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:STATe {param}')

	# noinspection PyTypeChecker
	def get_csuffix(self) -> enums.AvionicDmeChanSuff:
		"""SCPI: [SOURce<HW>]:[BB]:DME:CSUFfix \n
		Snippet: value: enums.AvionicDmeChanSuff = driver.source.bb.dme.get_csuffix() \n
		Sets the channel that is simulated. Standard compliant X and Y channels differ in the spacing between the two pulses of
		the pulse pair and the delay of the ground station. \n
			:return: csuffix: X| Y| ICAO
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:CSUFfix?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicDmeChanSuff)

	def set_csuffix(self, csuffix: enums.AvionicDmeChanSuff) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:CSUFfix \n
		Snippet: driver.source.bb.dme.set_csuffix(csuffix = enums.AvionicDmeChanSuff.ICAO) \n
		Sets the channel that is simulated. Standard compliant X and Y channels differ in the spacing between the two pulses of
		the pulse pair and the delay of the ground station. \n
			:param csuffix: X| Y| ICAO
		"""
		param = Conversions.enum_scalar_to_str(csuffix, enums.AvionicDmeChanSuff)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:CSUFfix {param}')

	def get_fall(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:FALL \n
		Snippet: value: float = driver.source.bb.dme.get_fall() \n
		Sets the fall time of the pulse (90% to 10% of peak voltage) . \n
			:return: fall: float Range: 0.5E-6 to 10E-6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:FALL?')
		return Conversions.str_to_float(response)

	def set_fall(self, fall: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:FALL \n
		Snippet: driver.source.bb.dme.set_fall(fall = 1.0) \n
		Sets the fall time of the pulse (90% to 10% of peak voltage) . \n
			:param fall: float Range: 0.5E-6 to 10E-6
		"""
		param = Conversions.decimal_value_to_str(fall)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:FALL {param}')

	def get_frequency(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:FREQuency \n
		Snippet: value: float = driver.source.bb.dme.get_frequency() \n
		Sets the carrier frequency of the signal. \n
			:return: carrier_freq: float Range: 100E3 to 6E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, carrier_freq: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:FREQuency \n
		Snippet: driver.source.bb.dme.set_frequency(carrier_freq = 1.0) \n
		Sets the carrier frequency of the signal. \n
			:param carrier_freq: float Range: 100E3 to 6E9
		"""
		param = Conversions.decimal_value_to_str(carrier_freq)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:FREQuency {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AvionicDmeMode:
		"""SCPI: [SOURce<HW>]:[BB]:DME:MODE \n
		Snippet: value: enums.AvionicDmeMode = driver.source.bb.dme.get_mode() \n
		Selects the mode of the DME modulation. The mode determines the signal type that is simulated. The exact timing of the
		signal for each mode is determined by the channel selected with[:SOURce<hw>][:BB]:DME:CSUFfix. \n
			:return: mode: INTerrogation| REPLy INTerrogation The interrogation signal of the airborne transmitter is simulated. REPLy The reply signal of the ground based transponder is simulated. The trigger is automatically set to external and the default trigger delay either to 50 us (channel X) or 56 us (channel Y) depending on the selected channel ([:SOURcehw][:BB]:DME:CSUFfix) . The interval between the pulse pairs can be set to a fixed value (repetition rate, [:SOURcehw][:BB]:DME:RATE) or to random generation (pulse squitter, [:SOURcehw][:BB]:DME:SQUitter) . The trigger signal is input via the Pulse Ext connector.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicDmeMode)

	def set_mode(self, mode: enums.AvionicDmeMode) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:MODE \n
		Snippet: driver.source.bb.dme.set_mode(mode = enums.AvionicDmeMode.INTerrogation) \n
		Selects the mode of the DME modulation. The mode determines the signal type that is simulated. The exact timing of the
		signal for each mode is determined by the channel selected with[:SOURce<hw>][:BB]:DME:CSUFfix. \n
			:param mode: INTerrogation| REPLy INTerrogation The interrogation signal of the airborne transmitter is simulated. REPLy The reply signal of the ground based transponder is simulated. The trigger is automatically set to external and the default trigger delay either to 50 us (channel X) or 56 us (channel Y) depending on the selected channel ([:SOURcehw][:BB]:DME:CSUFfix) . The interval between the pulse pairs can be set to a fixed value (repetition rate, [:SOURcehw][:BB]:DME:RATE) or to random generation (pulse squitter, [:SOURcehw][:BB]:DME:SQUitter) . The trigger signal is input via the Pulse Ext connector.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AvionicDmeMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:MODE {param}')

	def get_pps(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:PPS \n
		Snippet: value: float = driver.source.bb.dme.get_pps() \n
		Sets the spacing between the first and second pulse of a pulse pair (time between halfvoltage points on the leading edge
		of each pulse) . Available only for [:SOURce<hw>][:BB]:DME:SINGleOFF \n
			:return: pps: float Range: 1E-6 to 200E-6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:PPS?')
		return Conversions.str_to_float(response)

	def set_pps(self, pps: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:PPS \n
		Snippet: driver.source.bb.dme.set_pps(pps = 1.0) \n
		Sets the spacing between the first and second pulse of a pulse pair (time between halfvoltage points on the leading edge
		of each pulse) . Available only for [:SOURce<hw>][:BB]:DME:SINGleOFF \n
			:param pps: float Range: 1E-6 to 200E-6
		"""
		param = Conversions.decimal_value_to_str(pps)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:PPS {param}')

	def get_rate(self) -> int:
		"""SCPI: [SOURce<HW>]:[BB]:DME:RATE \n
		Snippet: value: int = driver.source.bb.dme.get_rate() \n
		If [:SOURce<hw>][:BB]:DME:MODE is set to INTerrogation, sets the pulse repetition rate. If [:SOURce<hw>][:BB]:DME:MODE is
		set to REPLy, indicates the mean pulse repetition rate in squitter mode. \n
			:return: rate: integer Range: 10 to 6000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:RATE?')
		return Conversions.str_to_int(response)

	def set_rate(self, rate: int) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:RATE \n
		Snippet: driver.source.bb.dme.set_rate(rate = 1) \n
		If [:SOURce<hw>][:BB]:DME:MODE is set to INTerrogation, sets the pulse repetition rate. If [:SOURce<hw>][:BB]:DME:MODE is
		set to REPLy, indicates the mean pulse repetition rate in squitter mode. \n
			:param rate: integer Range: 10 to 6000
		"""
		param = Conversions.decimal_value_to_str(rate)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:RATE {param}')

	def get_rise(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:RISE \n
		Snippet: value: float = driver.source.bb.dme.get_rise() \n
		Sets the rise time of the pulse (10% to 90% of peak voltage) . \n
			:return: rise: float Range: 0.5E-6 to 10E-6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:RISE?')
		return Conversions.str_to_float(response)

	def set_rise(self, rise: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:RISE \n
		Snippet: driver.source.bb.dme.set_rise(rise = 1.0) \n
		Sets the rise time of the pulse (10% to 90% of peak voltage) . \n
			:param rise: float Range: 0.5E-6 to 10E-6
		"""
		param = Conversions.decimal_value_to_str(rise)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:RISE {param}')

	# noinspection PyTypeChecker
	def get_shape(self) -> enums.AvionicDmePulsShap:
		"""SCPI: [SOURce<HW>]:[BB]:DME:SHAPe \n
		Snippet: value: enums.AvionicDmePulsShap = driver.source.bb.dme.get_shape() \n
		Sets the pulse shape. \n
			:return: shape: COS2| LIN| COS| GAUSs COS2| The rising edge is cos shaped and the falling edge is cos^2 shaped. LIN The falling and the rising edge of the pulse are shaped linear. COS The falling and the rising edge of the pulse are cos^2 shaped.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:SHAPe?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicDmePulsShap)

	def set_shape(self, shape: enums.AvionicDmePulsShap) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:SHAPe \n
		Snippet: driver.source.bb.dme.set_shape(shape = enums.AvionicDmePulsShap.COS) \n
		Sets the pulse shape. \n
			:param shape: COS2| LIN| COS| GAUSs COS2| The rising edge is cos shaped and the falling edge is cos^2 shaped. LIN The falling and the rising edge of the pulse are shaped linear. COS The falling and the rising edge of the pulse are cos^2 shaped.
		"""
		param = Conversions.enum_scalar_to_str(shape, enums.AvionicDmePulsShap)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:SHAPe {param}')

	def get_single(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:DME:SINGle \n
		Snippet: value: bool = driver.source.bb.dme.get_single() \n
		Activates/deactivates generation of a single test pulse. \n
			:return: single: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:SINGle?')
		return Conversions.str_to_bool(response)

	def set_single(self, single: bool) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:SINGle \n
		Snippet: driver.source.bb.dme.set_single(single = False) \n
		Activates/deactivates generation of a single test pulse. \n
			:param single: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(single)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:SINGle {param}')

	def get_squitter(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:DME:SQUitter \n
		Snippet: value: bool = driver.source.bb.dme.get_squitter() \n
		Activates/deactivates the random pulse repetition rate. The average repetition rate is 2700 pp/s. The pulse spacing is
		distributed randomly in the range of 60 us to about 1500 us according to EUROCAE EN-54 6.2.12. The squitter pulses are
		constantly sent by the ground station in order to ensure proper operation and in order to ease synchronization of the
		aircraft interrogator to the ground station. \n
			:return: squitter: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:SQUitter?')
		return Conversions.str_to_bool(response)

	def set_squitter(self, squitter: bool) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:SQUitter \n
		Snippet: driver.source.bb.dme.set_squitter(squitter = False) \n
		Activates/deactivates the random pulse repetition rate. The average repetition rate is 2700 pp/s. The pulse spacing is
		distributed randomly in the range of 60 us to about 1500 us according to EUROCAE EN-54 6.2.12. The squitter pulses are
		constantly sent by the ground station in order to ensure proper operation and in order to ease synchronization of the
		aircraft interrogator to the ground station. \n
			:param squitter: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(squitter)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:SQUitter {param}')

	def get_velocity(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:VELocity \n
		Snippet: value: float = driver.source.bb.dme.get_velocity() \n
		Sets the delay between the DME echo pulse signal and the original DME pulse signal. \n
			:return: dme_velocity: float Range: -1E4 to 1E4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:VELocity?')
		return Conversions.str_to_float(response)

	def set_velocity(self, dme_velocity: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:VELocity \n
		Snippet: driver.source.bb.dme.set_velocity(dme_velocity = 1.0) \n
		Sets the delay between the DME echo pulse signal and the original DME pulse signal. \n
			:param dme_velocity: float Range: -1E4 to 1E4
		"""
		param = Conversions.decimal_value_to_str(dme_velocity)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:VELocity {param}')

	def get_width(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:WIDTh \n
		Snippet: value: float = driver.source.bb.dme.get_width() \n
		Sets the pulse width (50% to 50% of peak voltage) . \n
			:return: width: float Range: 1E-6 to 100E-6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:WIDTh?')
		return Conversions.str_to_float(response)

	def set_width(self, width: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:WIDTh \n
		Snippet: driver.source.bb.dme.set_width(width = 1.0) \n
		Sets the pulse width (50% to 50% of peak voltage) . \n
			:param width: float Range: 1E-6 to 100E-6
		"""
		param = Conversions.decimal_value_to_str(width)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:WIDTh {param}')

	def clone(self) -> 'DmeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DmeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrampCls:
	"""Pramp commands group definition. 5 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pramp", core, parent)

	@property
	def bbOnly(self):
		"""bbOnly commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bbOnly'):
			from .BbOnly import BbOnlyCls
			self._bbOnly = BbOnlyCls(self._core, self._cmd_group)
		return self._bbOnly

	def get_fdelay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:FDELay \n
		Snippet: value: float = driver.source.bb.gsm.pramp.get_fdelay() \n
		The command sets the offset in the Falling edge of the ramp envelope at the end of a slot. A positive value causes a ramp
		delay and a negative value advances the ramp. The setting is expressed in symbols. \n
			:return: fdelay: float Range: -9 to 9, Unit: symbol
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GSM:PRAMp:FDELay?')
		return Conversions.str_to_float(response)

	def set_fdelay(self, fdelay: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:FDELay \n
		Snippet: driver.source.bb.gsm.pramp.set_fdelay(fdelay = 1.0) \n
		The command sets the offset in the Falling edge of the ramp envelope at the end of a slot. A positive value causes a ramp
		delay and a negative value advances the ramp. The setting is expressed in symbols. \n
			:param fdelay: float Range: -9 to 9, Unit: symbol
		"""
		param = Conversions.decimal_value_to_str(fdelay)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:PRAMp:FDELay {param}')

	def get_rdelay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:RDELay \n
		Snippet: value: float = driver.source.bb.gsm.pramp.get_rdelay() \n
		The command sets the offset in the Rising edge of the ramp envelope at the start of a slot. A positive value causes a
		ramp delay and a negative value advances the ramp. The setting is expressed in symbols. \n
			:return: rdelay: float Range: -9 to 9, Unit: symbol
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GSM:PRAMp:RDELay?')
		return Conversions.str_to_float(response)

	def set_rdelay(self, rdelay: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:RDELay \n
		Snippet: driver.source.bb.gsm.pramp.set_rdelay(rdelay = 1.0) \n
		The command sets the offset in the Rising edge of the ramp envelope at the start of a slot. A positive value causes a
		ramp delay and a negative value advances the ramp. The setting is expressed in symbols. \n
			:param rdelay: float Range: -9 to 9, Unit: symbol
		"""
		param = Conversions.decimal_value_to_str(rdelay)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:PRAMp:RDELay {param}')

	# noinspection PyTypeChecker
	def get_shape(self) -> enums.RampFunc:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:SHAPe \n
		Snippet: value: enums.RampFunc = driver.source.bb.gsm.pramp.get_shape() \n
		The command sets the edge shape of the ramp envelope. \n
			:return: shape: LINear| COSine LINear The transmitted power rises and falls linear fashion. COSine The transmitted power rises and falls in the shape of a cosine.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GSM:PRAMp:SHAPe?')
		return Conversions.str_to_scalar_enum(response, enums.RampFunc)

	def set_shape(self, shape: enums.RampFunc) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:SHAPe \n
		Snippet: driver.source.bb.gsm.pramp.set_shape(shape = enums.RampFunc.COSine) \n
		The command sets the edge shape of the ramp envelope. \n
			:param shape: LINear| COSine LINear The transmitted power rises and falls linear fashion. COSine The transmitted power rises and falls in the shape of a cosine.
		"""
		param = Conversions.enum_scalar_to_str(shape, enums.RampFunc)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:PRAMp:SHAPe {param}')

	def get_time(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:TIME \n
		Snippet: value: float = driver.source.bb.gsm.pramp.get_time() \n
		The command sets the edge slope of the ramp envelope. This specifies the number of symbols over which the switching
		operation is stretched when the transmitted power is turned on and off. \n
			:return: time: float Range: 0.3 to 16, Unit: symbol
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GSM:PRAMp:TIME?')
		return Conversions.str_to_float(response)

	def set_time(self, time: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:PRAMp:TIME \n
		Snippet: driver.source.bb.gsm.pramp.set_time(time = 1.0) \n
		The command sets the edge slope of the ramp envelope. This specifies the number of symbols over which the switching
		operation is stretched when the transmitted power is turned on and off. \n
			:param time: float Range: 0.3 to 16, Unit: symbol
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:PRAMp:TIME {param}')

	def clone(self) -> 'PrampCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PrampCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.ScrCodeMode, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:SCODe:MODE \n
		Snippet: driver.source.bb.w3Gpp.mstation.scode.mode.set(mode = enums.ScrCodeMode.LONG, mobileStation = repcap.MobileStation.Default) \n
		The command sets the type for the scrambling code. The scrambling code generator can also be deactivated for test
		purposes. SHORt is only standardized for the selection BB:W3GP:MST:MODE DPCDh and BB:W3GP:MST:MODE PCPCh. But it can also
		be generated for the PCPCH for test purposes. \n
			:param mode: LONG| SHORt| OFF
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ScrCodeMode)
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:SCODe:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, mobileStation=repcap.MobileStation.Default) -> enums.ScrCodeMode:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:SCODe:MODE \n
		Snippet: value: enums.ScrCodeMode = driver.source.bb.w3Gpp.mstation.scode.mode.get(mobileStation = repcap.MobileStation.Default) \n
		The command sets the type for the scrambling code. The scrambling code generator can also be deactivated for test
		purposes. SHORt is only standardized for the selection BB:W3GP:MST:MODE DPCDh and BB:W3GP:MST:MODE PCPCh. But it can also
		be generated for the PCPCH for test purposes. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: mode: LONG| SHORt| OFF"""
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:SCODe:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ScrCodeMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NiotCls:
	"""Niot commands group definition. 41 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("niot", core, parent)

	@property
	def arb(self):
		"""arb commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_arb'):
			from .Arb import ArbCls
			self._arb = ArbCls(self._core, self._cmd_group)
		return self._arb

	@property
	def dfreq(self):
		"""dfreq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfreq'):
			from .Dfreq import DfreqCls
			self._dfreq = DfreqCls(self._core, self._cmd_group)
		return self._dfreq

	@property
	def frc(self):
		"""frc commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_frc'):
			from .Frc import FrcCls
			self._frc = FrcCls(self._core, self._cmd_group)
		return self._frc

	@property
	def ghDisable(self):
		"""ghDisable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ghDisable'):
			from .GhDisable import GhDisableCls
			self._ghDisable = GhDisableCls(self._core, self._cmd_group)
		return self._ghDisable

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def npssim(self):
		"""npssim commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_npssim'):
			from .Npssim import NpssimCls
			self._npssim = NpssimCls(self._core, self._cmd_group)
		return self._npssim

	@property
	def ntransmiss(self):
		"""ntransmiss commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ntransmiss'):
			from .Ntransmiss import NtransmissCls
			self._ntransmiss = NtransmissCls(self._core, self._cmd_group)
		return self._ntransmiss

	@property
	def rbIndex(self):
		"""rbIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbIndex'):
			from .RbIndex import RbIndexCls
			self._rbIndex = RbIndexCls(self._core, self._cmd_group)
		return self._rbIndex

	@property
	def scSpacing(self):
		"""scSpacing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scSpacing'):
			from .ScSpacing import ScSpacingCls
			self._scSpacing = ScSpacingCls(self._core, self._cmd_group)
		return self._scSpacing

	@property
	def trans(self):
		"""trans commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_trans'):
			from .Trans import TransCls
			self._trans = TransCls(self._core, self._cmd_group)
		return self._trans

	def clone(self) -> 'NiotCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NiotCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NbCls:
	"""Nb commands group definition. 9 total commands, 0 Subgroups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nb", core, parent)

	def get_hoffset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:HOFFset \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.nb.get_hoffset() \n
		Sets the number of narrowbands between two consecutive MPDCCH or PDSCH hops. \n
			:return: hopping_offset: integer Range: 1 to 16
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:HOFFset?')
		return Conversions.str_to_int(response)

	def set_hoffset(self, hopping_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:HOFFset \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_hoffset(hopping_offset = 1) \n
		Sets the number of narrowbands between two consecutive MPDCCH or PDSCH hops. \n
			:param hopping_offset: integer Range: 1 to 16
		"""
		param = Conversions.decimal_value_to_str(hopping_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:HOFFset {param}')

	# noinspection PyTypeChecker
	def get_hopping(self) -> enums.NumbersD:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:HOPPing \n
		Snippet: value: enums.NumbersD = driver.source.bb.eutra.downlink.emtc.nb.get_hopping() \n
		Sets the number of narrowbands over which MPDCCH or PDSCH hops. \n
			:return: num_nb_hopping: 2| 4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:HOPPing?')
		return Conversions.str_to_scalar_enum(response, enums.NumbersD)

	def set_hopping(self, num_nb_hopping: enums.NumbersD) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:HOPPing \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_hopping(num_nb_hopping = enums.NumbersD._2) \n
		Sets the number of narrowbands over which MPDCCH or PDSCH hops. \n
			:param num_nb_hopping: 2| 4
		"""
		param = Conversions.enum_scalar_to_str(num_nb_hopping, enums.NumbersD)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:HOPPing {param}')

	# noinspection PyTypeChecker
	def get_ivla(self) -> enums.EutraIotHoppingIvl:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:IVLA \n
		Snippet: value: enums.EutraIotHoppingIvl = driver.source.bb.eutra.downlink.emtc.nb.get_ivla() \n
		Sets the number of consecutive subframes during which MPDCCH or PDSCH stays at the same narrowband before hopping to
		another narrowband. \n
			:return: hopping_ivla: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:IVLA?')
		return Conversions.str_to_scalar_enum(response, enums.EutraIotHoppingIvl)

	def set_ivla(self, hopping_ivla: enums.EutraIotHoppingIvl) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:IVLA \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_ivla(hopping_ivla = enums.EutraIotHoppingIvl.H1) \n
		Sets the number of consecutive subframes during which MPDCCH or PDSCH stays at the same narrowband before hopping to
		another narrowband. \n
			:param hopping_ivla: H1| H2| H4| H5| H8| H10| H16| H20| H40
		"""
		param = Conversions.enum_scalar_to_str(hopping_ivla, enums.EutraIotHoppingIvl)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:IVLA {param}')

	# noinspection PyTypeChecker
	def get_ivlb(self) -> enums.EutraIotHoppingIvl:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:IVLB \n
		Snippet: value: enums.EutraIotHoppingIvl = driver.source.bb.eutra.downlink.emtc.nb.get_ivlb() \n
		Sets the number of consecutive subframes during which MPDCCH or PDSCH stays at the same narrowband before hopping to
		another narrowband. \n
			:return: hopping_ivlb: H1| H2| H4| H5| H8| H10| H16| H20| H40
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:IVLB?')
		return Conversions.str_to_scalar_enum(response, enums.EutraIotHoppingIvl)

	def set_ivlb(self, hopping_ivlb: enums.EutraIotHoppingIvl) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:IVLB \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_ivlb(hopping_ivlb = enums.EutraIotHoppingIvl.H1) \n
		Sets the number of consecutive subframes during which MPDCCH or PDSCH stays at the same narrowband before hopping to
		another narrowband. \n
			:param hopping_ivlb: H1| H2| H4| H5| H8| H10| H16| H20| H40
		"""
		param = Conversions.enum_scalar_to_str(hopping_ivlb, enums.EutraIotHoppingIvl)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:IVLB {param}')

	def get_nn_bands(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:NNBands \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.nb.get_nn_bands() \n
		Queries the number of narrowbands. \n
			:return: num_narrowbands: integer Range: 1 to 16
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:NNBands?')
		return Conversions.str_to_int(response)

	def get_phopping(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:PHOPping \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.emtc.nb.get_phopping() \n
		Enables hopping for the random access. \n
			:return: paging_hopping: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:PHOPping?')
		return Conversions.str_to_bool(response)

	def set_phopping(self, paging_hopping: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:PHOPping \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_phopping(paging_hopping = False) \n
		Enables hopping for the random access. \n
			:param paging_hopping: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(paging_hopping)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:PHOPping {param}')

	def get_pstnb(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:PSTNb \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.nb.get_pstnb() \n
		Sets the first used narrowband, if hoping is enabeld. \n
			:return: paging_starting_n: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:PSTNb?')
		return Conversions.str_to_int(response)

	def set_pstnb(self, paging_starting_n: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:PSTNb \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_pstnb(paging_starting_n = 1) \n
		Sets the first used narrowband, if hoping is enabeld. \n
			:param paging_starting_n: integer Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(paging_starting_n)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:PSTNb {param}')

	def get_rhoppping(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:RHOPpping \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.emtc.nb.get_rhoppping() \n
		Enables hopping for the random access. \n
			:return: ra_hopping: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:RHOPpping?')
		return Conversions.str_to_bool(response)

	def set_rhoppping(self, ra_hopping: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:RHOPpping \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_rhoppping(ra_hopping = False) \n
		Enables hopping for the random access. \n
			:param ra_hopping: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(ra_hopping)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:RHOPpping {param}')

	def get_rstnb(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:RSTNb \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.nb.get_rstnb() \n
		Sets the first used narrowband, if hoping is enabeld. \n
			:return: ra_starting_nb: integer Range: 0 to 15
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:RSTNb?')
		return Conversions.str_to_int(response)

	def set_rstnb(self, ra_starting_nb: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:NB:RSTNb \n
		Snippet: driver.source.bb.eutra.downlink.emtc.nb.set_rstnb(ra_starting_nb = 1) \n
		Sets the first used narrowband, if hoping is enabeld. \n
			:param ra_starting_nb: integer Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(ra_starting_nb)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:NB:RSTNb {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrameCls:
	"""Frame commands group definition. 37 total commands, 5 Subgroups, 0 group commands
	Repeated Capability: FrameIx, default value after init: FrameIx.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frame", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_frameIx_get', 'repcap_frameIx_set', repcap.FrameIx.Nr1)

	def repcap_frameIx_set(self, frameIx: repcap.FrameIx) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to FrameIx.Default
		Default value after init: FrameIx.Nr1"""
		self._cmd_group.set_repcap_enum_value(frameIx)

	def repcap_frameIx_get(self) -> repcap.FrameIx:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def repetitions(self):
		"""repetitions commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_repetitions'):
			from .Repetitions import RepetitionsCls
			self._repetitions = RepetitionsCls(self._core, self._cmd_group)
		return self._repetitions

	@property
	def ulist(self):
		"""ulist commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_ulist'):
			from .Ulist import UlistCls
			self._ulist = UlistCls(self._core, self._cmd_group)
		return self._ulist

	@property
	def multiSlot(self):
		"""multiSlot commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_multiSlot'):
			from .MultiSlot import MultiSlotCls
			self._multiSlot = MultiSlotCls(self._core, self._cmd_group)
		return self._multiSlot

	@property
	def predefined(self):
		"""predefined commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_predefined'):
			from .Predefined import PredefinedCls
			self._predefined = PredefinedCls(self._core, self._cmd_group)
		return self._predefined

	@property
	def slot(self):
		"""slot commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_slot'):
			from .Slot import SlotCls
			self._slot = SlotCls(self._core, self._cmd_group)
		return self._slot

	def clone(self) -> 'FrameCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrameCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PformatCls:
	"""Pformat commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pformat", core, parent)

	def set(self, ppdu_format: enums.WlannFbPpduFormat, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:PFORmat \n
		Snippet: driver.source.bb.wlnn.fblock.pformat.set(ppdu_format = enums.WlannFbPpduFormat.MU, frameBlock = repcap.FrameBlock.Default) \n
		Sets the PPDU format. \n
			:param ppdu_format: SU| MU| SUEXt| TRIG SU HE SU (single-user) carries a single PSDU. The HE Signal A (HE-SIG-A) field is not repeated. MU HE MU (multi-user) carries multiple PSDUs to one or more users. SUEXt Carries a single PSDU. The HE-SIG-A field is repeated.
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.enum_scalar_to_str(ppdu_format, enums.WlannFbPpduFormat)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:PFORmat {param}')

	# noinspection PyTypeChecker
	def get(self, frameBlock=repcap.FrameBlock.Default) -> enums.WlannFbPpduFormat:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:PFORmat \n
		Snippet: value: enums.WlannFbPpduFormat = driver.source.bb.wlnn.fblock.pformat.get(frameBlock = repcap.FrameBlock.Default) \n
		Sets the PPDU format. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: ppdu_format: SU| MU| SUEXt| TRIG SU HE SU (single-user) carries a single PSDU. The HE Signal A (HE-SIG-A) field is not repeated. MU HE MU (multi-user) carries multiple PSDUs to one or more users. SUEXt Carries a single PSDU. The HE-SIG-A field is repeated."""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:PFORmat?')
		return Conversions.str_to_scalar_enum(response, enums.WlannFbPpduFormat)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CodewordCls:
	"""Codeword commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("codeword", core, parent)

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> enums.EutraCodeWordIdx:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[CELL<CCIDX>]:[SUBF<ST0>]:ALLoc<CH0>:PUSCh:CQI:CODWord \n
		Snippet: value: enums.EutraCodeWordIdx = driver.source.bb.eutra.uplink.cell.subf.alloc.pusch.cqi.codeword.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Queries the codeword the CQI is mapped to. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: cqi_code_word: CW1| CW2"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:CQI:CODWord?')
		return Conversions.str_to_scalar_enum(response, enums.EutraCodeWordIdx)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MibCls:
	"""Mib commands group definition. 10 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mib", core, parent)

	@property
	def asof(self):
		"""asof commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_asof'):
			from .Asof import AsofCls
			self._asof = AsofCls(self._core, self._cmd_group)
		return self._asof

	@property
	def cbarred(self):
		"""cbarred commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbarred'):
			from .Cbarred import CbarredCls
			self._cbarred = CbarredCls(self._core, self._cmd_group)
		return self._cbarred

	@property
	def csZero(self):
		"""csZero commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_csZero'):
			from .CsZero import CsZeroCls
			self._csZero = CsZeroCls(self._core, self._cmd_group)
		return self._csZero

	@property
	def ifrResel(self):
		"""ifrResel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ifrResel'):
			from .IfrResel import IfrReselCls
			self._ifrResel = IfrReselCls(self._core, self._cmd_group)
		return self._ifrResel

	@property
	def scOffset(self):
		"""scOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scOffset'):
			from .ScOffset import ScOffsetCls
			self._scOffset = ScOffsetCls(self._core, self._cmd_group)
		return self._scOffset

	@property
	def scsc(self):
		"""scsc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scsc'):
			from .Scsc import ScscCls
			self._scsc = ScscCls(self._core, self._cmd_group)
		return self._scsc

	@property
	def sfOffset(self):
		"""sfOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfOffset'):
			from .SfOffset import SfOffsetCls
			self._sfOffset = SfOffsetCls(self._core, self._cmd_group)
		return self._sfOffset

	@property
	def spare(self):
		"""spare commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_spare'):
			from .Spare import SpareCls
			self._spare = SpareCls(self._core, self._cmd_group)
		return self._spare

	@property
	def ssZero(self):
		"""ssZero commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssZero'):
			from .SsZero import SsZeroCls
			self._ssZero = SsZeroCls(self._core, self._cmd_group)
		return self._ssZero

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'MibCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MibCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	# noinspection PyTypeChecker
	def get_advanced(self) -> enums.AutoManualMode:
		"""SCPI: [SOURce<HW>]:SWEep:POWer:MODE:ADVanced \n
		Snippet: value: enums.AutoManualMode = driver.source.sweep.power.mode.get_advanced() \n
		No command help available \n
			:return: pow_mode_adv: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:SWEep:POWer:MODE:ADVanced?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)

	def set_advanced(self, pow_mode_adv: enums.AutoManualMode) -> None:
		"""SCPI: [SOURce<HW>]:SWEep:POWer:MODE:ADVanced \n
		Snippet: driver.source.sweep.power.mode.set_advanced(pow_mode_adv = enums.AutoManualMode.AUTO) \n
		No command help available \n
			:param pow_mode_adv: No help available
		"""
		param = Conversions.enum_scalar_to_str(pow_mode_adv, enums.AutoManualMode)
		self._core.io.write(f'SOURce<HwInstance>:SWEep:POWer:MODE:ADVanced {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.AutoManStep:
		"""SCPI: [SOURce<HW>]:SWEep:POWer:MODE \n
		Snippet: value: enums.AutoManStep = driver.source.sweep.power.mode.get_value() \n
		Sets the cycle mode for the level sweep. \n
			:return: mode: AUTO| MANual| STEP AUTO Each trigger triggers exactly one complete sweep. MANual The trigger system is not active. You can trigger every step individually with the command [:SOURcehw]:POWer:MANual. The level value increases at each step by the value that you define with [:SOURcehw]:POWer:STEP[:INCRement]. Values directly entered with the command [:SOURcehw]:POWer:MANual are not taken into account. STEP Each trigger triggers one sweep step only. The level increases by the value entered with [:SOURcehw]:POWer:STEP[:INCRement].
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:SWEep:POWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManStep)

	def set_value(self, mode: enums.AutoManStep) -> None:
		"""SCPI: [SOURce<HW>]:SWEep:POWer:MODE \n
		Snippet: driver.source.sweep.power.mode.set_value(mode = enums.AutoManStep.AUTO) \n
		Sets the cycle mode for the level sweep. \n
			:param mode: AUTO| MANual| STEP AUTO Each trigger triggers exactly one complete sweep. MANual The trigger system is not active. You can trigger every step individually with the command [:SOURcehw]:POWer:MANual. The level value increases at each step by the value that you define with [:SOURcehw]:POWer:STEP[:INCRement]. Values directly entered with the command [:SOURcehw]:POWer:MANual are not taken into account. STEP Each trigger triggers one sweep step only. The level increases by the value entered with [:SOURcehw]:POWer:STEP[:INCRement].
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AutoManStep)
		self._core.io.write(f'SOURce<HwInstance>:SWEep:POWer:MODE {param}')



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SeqCls:
	"""Seq commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("seq", core, parent)

	@property
	def cycShift(self):
		"""cycShift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cycShift'):
			from .CycShift import CycShiftCls
			self._cycShift = CycShiftCls(self._core, self._cmd_group)
		return self._cycShift

	@property
	def hopping(self):
		"""hopping commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hopping'):
			from .Hopping import HoppingCls
			self._hopping = HoppingCls(self._core, self._cmd_group)
		return self._hopping

	@property
	def id(self):
		"""id commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_id'):
			from .Id import IdCls
			self._id = IdCls(self._core, self._cmd_group)
		return self._id

	def clone(self) -> 'SeqCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SeqCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.GilterHigh, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:FILTer:TYPE \n
		Snippet: driver.source.bb.gsm.frame.slot.subChannel.user.filterPy.typePy.set(type_py = enums.GilterHigh.ENPShape, frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		Selects whether a Narrow Pulse Shape or a Wide Pulse Shape filter is used for the selected burst type and modulation. \n
			:param type_py: ENPShape| EWPShape
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.GilterHigh)
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:FILTer:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> enums.GilterHigh:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:FILTer:TYPE \n
		Snippet: value: enums.GilterHigh = driver.source.bb.gsm.frame.slot.subChannel.user.filterPy.typePy.get(frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		Selects whether a Narrow Pulse Shape or a Wide Pulse Shape filter is used for the selected burst type and modulation. \n
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: type_py: ENPShape| EWPShape"""
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:FILTer:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.GilterHigh)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserCls:
	"""User commands group definition. 22 total commands, 11 Subgroups, 0 group commands
	Repeated Capability: UserIx, default value after init: UserIx.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_userIx_get', 'repcap_userIx_set', repcap.UserIx.Nr1)

	def repcap_userIx_set(self, userIx: repcap.UserIx) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to UserIx.Default
		Default value after init: UserIx.Nr1"""
		self._cmd_group.set_repcap_enum_value(userIx)

	def repcap_userIx_get(self) -> repcap.UserIx:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def data(self):
		"""data commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def drclock(self):
		"""drclock commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_drclock'):
			from .Drclock import DrclockCls
			self._drclock = DrclockCls(self._core, self._cmd_group)
		return self._drclock

	@property
	def harq(self):
		"""harq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_harq'):
			from .Harq import HarqCls
			self._harq = HarqCls(self._core, self._cmd_group)
		return self._harq

	@property
	def ifactor(self):
		"""ifactor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ifactor'):
			from .Ifactor import IfactorCls
			self._ifactor = IfactorCls(self._core, self._cmd_group)
		return self._ifactor

	@property
	def mac(self):
		"""mac commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_mac'):
			from .Mac import MacCls
			self._mac = MacCls(self._core, self._cmd_group)
		return self._mac

	@property
	def packet(self):
		"""packet commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_packet'):
			from .Packet import PacketCls
			self._packet = PacketCls(self._core, self._cmd_group)
		return self._packet

	@property
	def psize(self):
		"""psize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psize'):
			from .Psize import PsizeCls
			self._psize = PsizeCls(self._core, self._cmd_group)
		return self._psize

	@property
	def rate(self):
		"""rate commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_rate'):
			from .Rate import RateCls
			self._rate = RateCls(self._core, self._cmd_group)
		return self._rate

	@property
	def rpc(self):
		"""rpc commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_rpc'):
			from .Rpc import RpcCls
			self._rpc = RpcCls(self._core, self._cmd_group)
		return self._rpc

	@property
	def scount(self):
		"""scount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scount'):
			from .Scount import ScountCls
			self._scount = ScountCls(self._core, self._cmd_group)
		return self._scount

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'UserCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UserCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrRateCls:
	"""PrRate commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prRate", core, parent)

	def get_ok(self) -> bool:
		"""SCPI: [SOURce<HW>]:DME:ANALysis:PRRate:OK \n
		Snippet: value: bool = driver.source.dme.analysis.prRate.get_ok() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:DME:ANALysis:PRRate:OK?')
		return Conversions.str_to_bool(response)

	def set_ok(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:DME:ANALysis:PRRate:OK \n
		Snippet: driver.source.dme.analysis.prRate.set_ok(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:DME:ANALysis:PRRate:OK {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:DME:ANALysis:PRRate:STATe \n
		Snippet: value: bool = driver.source.dme.analysis.prRate.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:DME:ANALysis:PRRate:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:DME:ANALysis:PRRate:STATe \n
		Snippet: driver.source.dme.analysis.prRate.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:DME:ANALysis:PRRate:STATe {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 39 total commands, 11 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	@property
	def beidou(self):
		"""beidou commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_beidou'):
			from .Beidou import BeidouCls
			self._beidou = BeidouCls(self._core, self._cmd_group)
		return self._beidou

	@property
	def date(self):
		"""date commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_date'):
			from .Date import DateCls
			self._date = DateCls(self._core, self._cmd_group)
		return self._date

	@property
	def galileo(self):
		"""galileo commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_galileo'):
			from .Galileo import GalileoCls
			self._galileo = GalileoCls(self._core, self._cmd_group)
		return self._galileo

	@property
	def glonass(self):
		"""glonass commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_glonass'):
			from .Glonass import GlonassCls
			self._glonass = GlonassCls(self._core, self._cmd_group)
		return self._glonass

	@property
	def gps(self):
		"""gps commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_gps'):
			from .Gps import GpsCls
			self._gps = GpsCls(self._core, self._cmd_group)
		return self._gps

	@property
	def navic(self):
		"""navic commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_navic'):
			from .Navic import NavicCls
			self._navic = NavicCls(self._core, self._cmd_group)
		return self._navic

	@property
	def qzss(self):
		"""qzss commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_qzss'):
			from .Qzss import QzssCls
			self._qzss = QzssCls(self._core, self._cmd_group)
		return self._qzss

	@property
	def sbas(self):
		"""sbas commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_sbas'):
			from .Sbas import SbasCls
			self._sbas = SbasCls(self._core, self._cmd_group)
		return self._sbas

	@property
	def scTime(self):
		"""scTime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scTime'):
			from .ScTime import ScTimeCls
			self._scTime = ScTimeCls(self._core, self._cmd_group)
		return self._scTime

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_time'):
			from .Time import TimeCls
			self._time = TimeCls(self._core, self._cmd_group)
		return self._time

	@property
	def utc(self):
		"""utc commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_utc'):
			from .Utc import UtcCls
			self._utc = UtcCls(self._core, self._cmd_group)
		return self._utc

	# noinspection PyTypeChecker
	def get_tbasis(self) -> enums.TimeBasis:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:TBASis \n
		Snippet: value: enums.TimeBasis = driver.source.bb.gnss.time.start.get_tbasis() \n
		Determines the time basis used to enter the simulation start time. \n
			:return: system_time: UTC| GPS| GST| GLO| BDT| NAV
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TIME:STARt:TBASis?')
		return Conversions.str_to_scalar_enum(response, enums.TimeBasis)

	def set_tbasis(self, system_time: enums.TimeBasis) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:TBASis \n
		Snippet: driver.source.bb.gnss.time.start.set_tbasis(system_time = enums.TimeBasis.BDT) \n
		Determines the time basis used to enter the simulation start time. \n
			:param system_time: UTC| GPS| GST| GLO| BDT| NAV
		"""
		param = Conversions.enum_scalar_to_str(system_time, enums.TimeBasis)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TIME:STARt:TBASis {param}')

	def get_to_week(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:TOWeek \n
		Snippet: value: float = driver.source.bb.gnss.time.start.get_to_week() \n
		If time base is GPS or GST, sets the simulation start time within week set with the command
		[:SOURce<hw>]:BB:GNSS:TIME:STARt:WNUMber. \n
			:return: tow: float Number of seconds since the beginning of the week Range: 0 to 604799.999
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TIME:STARt:TOWeek?')
		return Conversions.str_to_float(response)

	def set_to_week(self, tow: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:TOWeek \n
		Snippet: driver.source.bb.gnss.time.start.set_to_week(tow = 1.0) \n
		If time base is GPS or GST, sets the simulation start time within week set with the command
		[:SOURce<hw>]:BB:GNSS:TIME:STARt:WNUMber. \n
			:param tow: float Number of seconds since the beginning of the week Range: 0 to 604799.999
		"""
		param = Conversions.decimal_value_to_str(tow)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TIME:STARt:TOWeek {param}')

	def get_wnumber(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:WNUMber \n
		Snippet: value: int = driver.source.bb.gnss.time.start.get_wnumber() \n
		If time base is GPS or GST, sets the week number (WN) . \n
			:return: week: integer The weeks are numbered starting from a reference time point (WN_REF=0) , that depends on the navigation standard. Range: 0 to 9999*53
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TIME:STARt:WNUMber?')
		return Conversions.str_to_int(response)

	def set_wnumber(self, week: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:WNUMber \n
		Snippet: driver.source.bb.gnss.time.start.set_wnumber(week = 1) \n
		If time base is GPS or GST, sets the week number (WN) . \n
			:param week: integer The weeks are numbered starting from a reference time point (WN_REF=0) , that depends on the navigation standard. Range: 0 to 9999*53
		"""
		param = Conversions.decimal_value_to_str(week)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TIME:STARt:WNUMber {param}')

	def clone(self) -> 'StartCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StartCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsvCls:
	"""Csv commands group definition. 21 total commands, 6 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csv", core, parent)

	@property
	def acceleration(self):
		"""acceleration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_acceleration'):
			from .Acceleration import AccelerationCls
			self._acceleration = AccelerationCls(self._core, self._cmd_group)
		return self._acceleration

	@property
	def attitude(self):
		"""attitude commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_attitude'):
			from .Attitude import AttitudeCls
			self._attitude = AttitudeCls(self._core, self._cmd_group)
		return self._attitude

	@property
	def jerk(self):
		"""jerk commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_jerk'):
			from .Jerk import JerkCls
			self._jerk = JerkCls(self._core, self._cmd_group)
		return self._jerk

	@property
	def position(self):
		"""position commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_position'):
			from .Position import PositionCls
			self._position = PositionCls(self._core, self._cmd_group)
		return self._position

	@property
	def select(self):
		"""select commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def velocity(self):
		"""velocity commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_velocity'):
			from .Velocity import VelocityCls
			self._velocity = VelocityCls(self._core, self._cmd_group)
		return self._velocity

	def get_aoffset(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:AOFFset \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_aoffset() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:AOFFset?')
		return Conversions.str_to_bool(response)

	def set_aoffset(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:AOFFset \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_aoffset(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:AOFFset {param}')

	def get_gdop(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:GDOP \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_gdop() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:GDOP?')
		return Conversions.str_to_bool(response)

	def set_gdop(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:GDOP \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_gdop(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:GDOP {param}')

	def get_gspeed(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:GSPeed \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_gspeed() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:GSPeed?')
		return Conversions.str_to_bool(response)

	def set_gspeed(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:GSPeed \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_gspeed(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:GSPeed {param}')

	def get_hdop(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:HDOP \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_hdop() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:HDOP?')
		return Conversions.str_to_bool(response)

	def set_hdop(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:HDOP \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_hdop(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:HDOP {param}')

	def get_pdop(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:PDOP \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_pdop() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:PDOP?')
		return Conversions.str_to_bool(response)

	def set_pdop(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:PDOP \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_pdop(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:PDOP {param}')

	def get_svs(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:SVS \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_svs() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:SVS?')
		return Conversions.str_to_bool(response)

	def set_svs(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:SVS \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_svs(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:SVS {param}')

	def get_tdop(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:TDOP \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_tdop() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:TDOP?')
		return Conversions.str_to_bool(response)

	def set_tdop(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:TDOP \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_tdop(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:TDOP {param}')

	def get_vdop(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:VDOP \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.get_vdop() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:VDOP?')
		return Conversions.str_to_bool(response)

	def set_vdop(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:VDOP \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.set_vdop(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:VDOP {param}')

	def clone(self) -> 'CsvCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CsvCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ItypeCls:
	"""Itype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("itype", core, parent)

	def set(self, interface_type: enums.HilIfc, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:HIL:ITYPe \n
		Snippet: driver.source.bb.gnss.receiver.v.hil.itype.set(interface_type = enums.HilIfc.SCPI, vehicle = repcap.Vehicle.Default) \n
		Set the interface type for the remote communication between R&S SMBV100B and the control application. \n
			:param interface_type: SCPI| UDP
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
		"""
		param = Conversions.enum_scalar_to_str(interface_type, enums.HilIfc)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:HIL:ITYPe {param}')

	# noinspection PyTypeChecker
	def get(self, vehicle=repcap.Vehicle.Default) -> enums.HilIfc:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:HIL:ITYPe \n
		Snippet: value: enums.HilIfc = driver.source.bb.gnss.receiver.v.hil.itype.get(vehicle = repcap.Vehicle.Default) \n
		Set the interface type for the remote communication between R&S SMBV100B and the control application. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: interface_type: SCPI| UDP"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:HIL:ITYPe?')
		return Conversions.str_to_scalar_enum(response, enums.HilIfc)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VorCls:
	"""Vor commands group definition. 45 total commands, 10 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("vor", core, parent)

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def trigger(self):
		"""trigger commands group. 4 Sub-classes, 4 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def comid(self):
		"""comid commands group. 1 Sub-classes, 10 commands."""
		if not hasattr(self, '_comid'):
			from .Comid import ComidCls
			self._comid = ComidCls(self._core, self._cmd_group)
		return self._comid

	@property
	def icao(self):
		"""icao commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_icao'):
			from .Icao import IcaoCls
			self._icao = IcaoCls(self._core, self._cmd_group)
		return self._icao

	@property
	def reference(self):
		"""reference commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	@property
	def subcarrier(self):
		"""subcarrier commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_subcarrier'):
			from .Subcarrier import SubcarrierCls
			self._subcarrier = SubcarrierCls(self._core, self._cmd_group)
		return self._subcarrier

	@property
	def var(self):
		"""var commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_var'):
			from .Var import VarCls
			self._var = VarCls(self._core, self._cmd_group)
		return self._var

	@property
	def bangle(self):
		"""bangle commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_bangle'):
			from .Bangle import BangleCls
			self._bangle = BangleCls(self._core, self._cmd_group)
		return self._bangle

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:VOR:PRESet \n
		Snippet: driver.source.bb.vor.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:VOR|ILS|DME:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:VOR:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:VOR:PRESet \n
		Snippet: driver.source.bb.vor.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:VOR|ILS|DME:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:VOR:PRESet', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:VOR:STATe \n
		Snippet: value: bool = driver.source.bb.vor.get_state() \n
		Activates/deactivates the avionic standard. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:VOR:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:VOR:STATe \n
		Snippet: driver.source.bb.vor.set_state(state = False) \n
		Activates/deactivates the avionic standard. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:VOR:STATe {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AvionicVorMode:
		"""SCPI: [SOURce<HW>]:[BB]:VOR:MODE \n
		Snippet: value: enums.AvionicVorMode = driver.source.bb.vor.get_mode() \n
		Sets the operating mode for the VOR modulation signal. \n
			:return: mode: NORM| VAR| SUBCarrier| FMSubcarrier NORM VOR modulation is active. VAR Amplitude modulation of the output signal with the variable signal component (30Hz signal content) of the VOR signal. The modulation depth of the 30 Hz signal can be set with [:SOURcehw][:BB]:VOR:VAR[:DEPTh]. SUBCarrier Amplitude modulation of the output signal with the unmodulated FM carrier (9960Hz) of the VOR signal. The modulation depth of the 30 Hz signal can be set with [:SOURcehw][:BB]:VOR:SUBCarrier:DEPTh. FMSubcarrier Amplitude modulation of the output signal with the frequency modulated FM carrier (9960Hz) of the VOR signal. The modulation depth of the 30 Hz signal can be set with [:SOURcehw][:BB]:VOR:SUBCarrier:DEPTh. The frequency deviation can be set with [:SOURcehw][:BB]:VOR:REFerence[:DEViation].
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:VOR:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicVorMode)

	def set_mode(self, mode: enums.AvionicVorMode) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:VOR:MODE \n
		Snippet: driver.source.bb.vor.set_mode(mode = enums.AvionicVorMode.FMSubcarrier) \n
		Sets the operating mode for the VOR modulation signal. \n
			:param mode: NORM| VAR| SUBCarrier| FMSubcarrier NORM VOR modulation is active. VAR Amplitude modulation of the output signal with the variable signal component (30Hz signal content) of the VOR signal. The modulation depth of the 30 Hz signal can be set with [:SOURcehw][:BB]:VOR:VAR[:DEPTh]. SUBCarrier Amplitude modulation of the output signal with the unmodulated FM carrier (9960Hz) of the VOR signal. The modulation depth of the 30 Hz signal can be set with [:SOURcehw][:BB]:VOR:SUBCarrier:DEPTh. FMSubcarrier Amplitude modulation of the output signal with the frequency modulated FM carrier (9960Hz) of the VOR signal. The modulation depth of the 30 Hz signal can be set with [:SOURcehw][:BB]:VOR:SUBCarrier:DEPTh. The frequency deviation can be set with [:SOURcehw][:BB]:VOR:REFerence[:DEViation].
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AvionicVorMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:VOR:MODE {param}')

	def clone(self) -> 'VorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = VorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.TranRecSampFactMode:
		"""SCPI: [SOURce<HW>]:BB:GRAPhics:SRATe:MODE \n
		Snippet: value: enums.TranRecSampFactMode = driver.source.bb.graphics.symbolRate.get_mode() \n
		Sets how the time resolution of the signal is determined. Maximum resolution corresponds to a diagram covering the entire
		signal bandwidth. The higher the resolution is, the shorter the length of the displayed signal segment will be for the
		specified recording depth. \n
			:return: mode: AUTO| FULL| USER
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GRAPhics:SRATe:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TranRecSampFactMode)

	def set_mode(self, mode: enums.TranRecSampFactMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:GRAPhics:SRATe:MODE \n
		Snippet: driver.source.bb.graphics.symbolRate.set_mode(mode = enums.TranRecSampFactMode.AUTO) \n
		Sets how the time resolution of the signal is determined. Maximum resolution corresponds to a diagram covering the entire
		signal bandwidth. The higher the resolution is, the shorter the length of the displayed signal segment will be for the
		specified recording depth. \n
			:param mode: AUTO| FULL| USER
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.TranRecSampFactMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:GRAPhics:SRATe:MODE {param}')

	def get_user(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GRAPhics:SRATe:USER \n
		Snippet: value: float = driver.source.bb.graphics.symbolRate.get_user() \n
		(Enabled for BB:GRAPH:SRAT:MODE USER) Selects the signal bandwidth for the diagram. The setting range moves between the
		minimum and maximum bandwidth which is possible for the selected graphical signal display. The selection is made
		graphically by moving the pointer. \n
			:return: user: float Range: 0.01 to 100, Unit: PCT
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GRAPhics:SRATe:USER?')
		return Conversions.str_to_float(response)

	def set_user(self, user: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GRAPhics:SRATe:USER \n
		Snippet: driver.source.bb.graphics.symbolRate.set_user(user = 1.0) \n
		(Enabled for BB:GRAPH:SRAT:MODE USER) Selects the signal bandwidth for the diagram. The setting range moves between the
		minimum and maximum bandwidth which is possible for the selected graphical signal display. The selection is made
		graphically by moving the pointer. \n
			:param user: float Range: 0.01 to 100, Unit: PCT
		"""
		param = Conversions.decimal_value_to_str(user)
		self._core.io.write(f'SOURce<HwInstance>:BB:GRAPhics:SRATe:USER {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 9023 total commands, 34 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def adf(self):
		"""adf commands group. 3 Sub-classes, 2 commands."""
		if not hasattr(self, '_adf'):
			from .Adf import AdfCls
			self._adf = AdfCls(self._core, self._cmd_group)
		return self._adf

	@property
	def am(self):
		"""am commands group. 5 Sub-classes, 1 commands."""
		if not hasattr(self, '_am'):
			from .Am import AmCls
			self._am = AmCls(self._core, self._cmd_group)
		return self._am

	@property
	def areGenerator(self):
		"""areGenerator commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_areGenerator'):
			from .AreGenerator import AreGeneratorCls
			self._areGenerator = AreGeneratorCls(self._core, self._cmd_group)
		return self._areGenerator

	@property
	def awgn(self):
		"""awgn commands group. 5 Sub-classes, 5 commands."""
		if not hasattr(self, '_awgn'):
			from .Awgn import AwgnCls
			self._awgn = AwgnCls(self._core, self._cmd_group)
		return self._awgn

	@property
	def bb(self):
		"""bb commands group. 31 Sub-classes, 6 commands."""
		if not hasattr(self, '_bb'):
			from .Bb import BbCls
			self._bb = BbCls(self._core, self._cmd_group)
		return self._bb

	@property
	def bbin(self):
		"""bbin commands group. 7 Sub-classes, 9 commands."""
		if not hasattr(self, '_bbin'):
			from .Bbin import BbinCls
			self._bbin = BbinCls(self._core, self._cmd_group)
		return self._bbin

	@property
	def combined(self):
		"""combined commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_combined'):
			from .Combined import CombinedCls
			self._combined = CombinedCls(self._core, self._cmd_group)
		return self._combined

	@property
	def correction(self):
		"""correction commands group. 4 Sub-classes, 2 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def dme(self):
		"""dme commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_dme'):
			from .Dme import DmeCls
			self._dme = DmeCls(self._core, self._cmd_group)
		return self._dme

	@property
	def efrontend(self):
		"""efrontend commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_efrontend'):
			from .Efrontend import EfrontendCls
			self._efrontend = EfrontendCls(self._core, self._cmd_group)
		return self._efrontend

	@property
	def fm(self):
		"""fm commands group. 5 Sub-classes, 3 commands."""
		if not hasattr(self, '_fm'):
			from .Fm import FmCls
			self._fm = FmCls(self._core, self._cmd_group)
		return self._fm

	@property
	def frequency(self):
		"""frequency commands group. 4 Sub-classes, 9 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def freqSweep(self):
		"""freqSweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqSweep'):
			from .FreqSweep import FreqSweepCls
			self._freqSweep = FreqSweepCls(self._core, self._cmd_group)
		return self._freqSweep

	@property
	def ils(self):
		"""ils commands group. 7 Sub-classes, 2 commands."""
		if not hasattr(self, '_ils'):
			from .Ils import IlsCls
			self._ils = IlsCls(self._core, self._cmd_group)
		return self._ils

	@property
	def inputPy(self):
		"""inputPy commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def iq(self):
		"""iq commands group. 6 Sub-classes, 5 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def lffSweep(self):
		"""lffSweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_lffSweep'):
			from .LffSweep import LffSweepCls
			self._lffSweep = LffSweepCls(self._core, self._cmd_group)
		return self._lffSweep

	@property
	def lfOutput(self):
		"""lfOutput commands group. 8 Sub-classes, 3 commands."""
		if not hasattr(self, '_lfOutput'):
			from .LfOutput import LfOutputCls
			self._lfOutput = LfOutputCls(self._core, self._cmd_group)
		return self._lfOutput

	@property
	def listPy(self):
		"""listPy commands group. 8 Sub-classes, 8 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def mbeacon(self):
		"""mbeacon commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mbeacon'):
			from .Mbeacon import MbeaconCls
			self._mbeacon = MbeaconCls(self._core, self._cmd_group)
		return self._mbeacon

	@property
	def modulation(self):
		"""modulation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def noise(self):
		"""noise commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_noise'):
			from .Noise import NoiseCls
			self._noise = NoiseCls(self._core, self._cmd_group)
		return self._noise

	@property
	def occupy(self):
		"""occupy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_occupy'):
			from .Occupy import OccupyCls
			self._occupy = OccupyCls(self._core, self._cmd_group)
		return self._occupy

	@property
	def path(self):
		"""path commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_path'):
			from .Path import PathCls
			self._path = PathCls(self._core, self._cmd_group)
		return self._path

	@property
	def pgenerator(self):
		"""pgenerator commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_pgenerator'):
			from .Pgenerator import PgeneratorCls
			self._pgenerator = PgeneratorCls(self._core, self._cmd_group)
		return self._pgenerator

	@property
	def phase(self):
		"""phase commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import PhaseCls
			self._phase = PhaseCls(self._core, self._cmd_group)
		return self._phase

	@property
	def pm(self):
		"""pm commands group. 5 Sub-classes, 3 commands."""
		if not hasattr(self, '_pm'):
			from .Pm import PmCls
			self._pm = PmCls(self._core, self._cmd_group)
		return self._pm

	@property
	def power(self):
		"""power commands group. 8 Sub-classes, 10 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def psweep(self):
		"""psweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_psweep'):
			from .Psweep import PsweepCls
			self._psweep = PsweepCls(self._core, self._cmd_group)
		return self._psweep

	@property
	def pulm(self):
		"""pulm commands group. 5 Sub-classes, 9 commands."""
		if not hasattr(self, '_pulm'):
			from .Pulm import PulmCls
			self._pulm = PulmCls(self._core, self._cmd_group)
		return self._pulm

	@property
	def roscillator(self):
		"""roscillator commands group. 3 Sub-classes, 2 commands."""
		if not hasattr(self, '_roscillator'):
			from .Roscillator import RoscillatorCls
			self._roscillator = RoscillatorCls(self._core, self._cmd_group)
		return self._roscillator

	@property
	def sweep(self):
		"""sweep commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def valRf(self):
		"""valRf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_valRf'):
			from .ValRf import ValRfCls
			self._valRf = ValRfCls(self._core, self._cmd_group)
		return self._valRf

	@property
	def vor(self):
		"""vor commands group. 3 Sub-classes, 2 commands."""
		if not hasattr(self, '_vor'):
			from .Vor import VorCls
			self._vor = VorCls(self._core, self._cmd_group)
		return self._vor

	def preset(self) -> None:
		"""SCPI: SOURce<HW>:PRESet \n
		Snippet: driver.source.preset() \n
		Presets all parameters which are related to the selected signal path. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SOURce<HW>:PRESet \n
		Snippet: driver.source.preset_with_opc() \n
		Presets all parameters which are related to the selected signal path. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:PRESet', opc_timeout_ms)

	def clone(self) -> 'SourceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SourceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HsdpaCls:
	"""Hsdpa commands group definition. 48 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hsdpa", core, parent)

	@property
	def bmode(self):
		"""bmode commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bmode'):
			from .Bmode import BmodeCls
			self._bmode = BmodeCls(self._core, self._cmd_group)
		return self._bmode

	@property
	def cvpb(self):
		"""cvpb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cvpb'):
			from .Cvpb import CvpbCls
			self._cvpb = CvpbCls(self._core, self._cmd_group)
		return self._cvpb

	@property
	def hset(self):
		"""hset commands group. 29 Sub-classes, 2 commands."""
		if not hasattr(self, '_hset'):
			from .Hset import HsetCls
			self._hset = HsetCls(self._core, self._cmd_group)
		return self._hset

	@property
	def mimo(self):
		"""mimo commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_mimo'):
			from .Mimo import MimoCls
			self._mimo = MimoCls(self._core, self._cmd_group)
		return self._mimo

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def prsr(self):
		"""prsr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prsr'):
			from .Prsr import PrsrCls
			self._prsr = PrsrCls(self._core, self._cmd_group)
		return self._prsr

	@property
	def psbs(self):
		"""psbs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psbs'):
			from .Psbs import PsbsCls
			self._psbs = PsbsCls(self._core, self._cmd_group)
		return self._psbs

	@property
	def sformat(self):
		"""sformat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sformat'):
			from .Sformat import SformatCls
			self._sformat = SformatCls(self._core, self._cmd_group)
		return self._sformat

	@property
	def ttiDistance(self):
		"""ttiDistance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttiDistance'):
			from .TtiDistance import TtiDistanceCls
			self._ttiDistance = TtiDistanceCls(self._core, self._cmd_group)
		return self._ttiDistance

	def clone(self) -> 'HsdpaCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HsdpaCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ...........Internal.RepeatedCapability import RepeatedCapability
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BetaCls:
	"""Beta commands group definition. 2 total commands, 1 Subgroups, 1 group commands
	Repeated Capability: BetaNull, default value after init: BetaNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("beta", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_betaNull_get', 'repcap_betaNull_set', repcap.BetaNull.Nr0)

	def repcap_betaNull_set(self, betaNull: repcap.BetaNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to BetaNull.Default
		Default value after init: BetaNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(betaNull)

	def repcap_betaNull_get(self) -> repcap.BetaNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def unscaled(self):
		"""unscaled commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_unscaled'):
			from .Unscaled import UnscaledCls
			self._unscaled = UnscaledCls(self._core, self._cmd_group)
		return self._unscaled

	def set(self, beta: int, betaNull=repcap.BetaNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:GPS:NMESsage:CNAV:IONospheric:BETA<CH0> \n
		Snippet: driver.source.bb.gnss.atmospheric.gps.nmessage.cnav.ionospheric.beta.set(beta = 1, betaNull = repcap.BetaNull.Default) \n
		Sets the parameters beta_0 to beta_3 of the satellite's navigation message. \n
			:param beta: integer Range: -128 to 127
			:param betaNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Beta')
		"""
		param = Conversions.decimal_value_to_str(beta)
		betaNull_cmd_val = self._cmd_group.get_repcap_cmd_value(betaNull, repcap.BetaNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:GPS:NMESsage:CNAV:IONospheric:BETA{betaNull_cmd_val} {param}')

	def get(self, betaNull=repcap.BetaNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:GPS:NMESsage:CNAV:IONospheric:BETA<CH0> \n
		Snippet: value: int = driver.source.bb.gnss.atmospheric.gps.nmessage.cnav.ionospheric.beta.get(betaNull = repcap.BetaNull.Default) \n
		Sets the parameters beta_0 to beta_3 of the satellite's navigation message. \n
			:param betaNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Beta')
			:return: beta: integer Range: -128 to 127"""
		betaNull_cmd_val = self._cmd_group.get_repcap_cmd_value(betaNull, repcap.BetaNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:GPS:NMESsage:CNAV:IONospheric:BETA{betaNull_cmd_val}?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'BetaCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BetaCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NiotCls:
	"""Niot commands group definition. 12 total commands, 12 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("niot", core, parent)

	@property
	def cell(self):
		"""cell commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cell'):
			from .Cell import CellCls
			self._cell = CellCls(self._core, self._cmd_group)
		return self._cell

	@property
	def cidGroup(self):
		"""cidGroup commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cidGroup'):
			from .CidGroup import CidGroupCls
			self._cidGroup = CidGroupCls(self._core, self._cmd_group)
		return self._cidGroup

	@property
	def crsSeq(self):
		"""crsSeq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_crsSeq'):
			from .CrsSeq import CrsSeqCls
			self._crsSeq = CrsSeqCls(self._core, self._cmd_group)
		return self._crsSeq

	@property
	def dfreq(self):
		"""dfreq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfreq'):
			from .Dfreq import DfreqCls
			self._dfreq = DfreqCls(self._core, self._cmd_group)
		return self._dfreq

	@property
	def gbrbIdx(self):
		"""gbrbIdx commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gbrbIdx'):
			from .GbrbIdx import GbrbIdxCls
			self._gbrbIdx = GbrbIdxCls(self._core, self._cmd_group)
		return self._gbrbIdx

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def nvsf(self):
		"""nvsf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nvsf'):
			from .Nvsf import NvsfCls
			self._nvsf = NvsfCls(self._core, self._cmd_group)
		return self._nvsf

	@property
	def rbIdx(self):
		"""rbIdx commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbIdx'):
			from .RbIdx import RbIdxCls
			self._rbIdx = RbIdxCls(self._core, self._cmd_group)
		return self._rbIdx

	@property
	def sf(self):
		"""sf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sf'):
			from .Sf import SfCls
			self._sf = SfCls(self._core, self._cmd_group)
		return self._sf

	@property
	def sfall(self):
		"""sfall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfall'):
			from .Sfall import SfallCls
			self._sfall = SfallCls(self._core, self._cmd_group)
		return self._sfall

	@property
	def sfnn(self):
		"""sfnn commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfnn'):
			from .Sfnn import SfnnCls
			self._sfnn = SfnnCls(self._core, self._cmd_group)
		return self._sfnn

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'NiotCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NiotCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
